@@ -189,8 +189,7 @@ bool Application::parseCommandLineArgs() {
   QCommandLineOption setWallpaperOption(QStringList() << "w" << "set-wallpaper", tr("Set desktop wallpaper from image FILE"), tr("FILE"));
   parser.addOption(setWallpaperOption);
 
-  // don't translate list of modes in description, please
-  QCommandLineOption wallpaperModeOption("wallpaper-mode", tr("Set mode of desktop wallpaper. MODE=(color|stretch|fit|center|tile)"), tr("MODE"));
+  QCommandLineOption wallpaperModeOption("wallpaper-mode", tr("Set mode of desktop wallpaper. MODE=(%1)").arg("color|stretch|fit|center|tile"), tr("MODE"));
   parser.addOption(wallpaperModeOption);
 
   QCommandLineOption showPrefOption("show-pref", tr("Open Preferences dialog on the page with the specified name"), tr("NAME"));
@@ -518,7 +517,7 @@ void Application::preferences(QString page) {
     preferencesDialog_ = new PreferencesDialog(page);
   }
   else {
-    // TODO: set page
+    preferencesDialog_.data()->selectPage(page);
   }
   preferencesDialog_.data()->show();
   preferencesDialog_.data()->raise();
