@@ -45,6 +45,9 @@ public:
   const QColor& shadowColor() const {
     return shadowColor_;
   }
+  void setMargins(QSize margins) {
+    margins_ = margins.expandedTo(QSize(0, 0));
+  }
 
 private:
   void drawText(QPainter* painter, QStyleOptionViewItemV4& opt, QRectF& textRect) const;
@@ -53,6 +56,7 @@ private:
   QListView* view_;
   QIcon symlinkIcon_;
   QColor shadowColor_;
+  QSize margins_;
 };
 
 }
